@@ -1,4 +1,6 @@
 # flake8: NOQA: E501
+"""Sphinx configuration for libtmux."""
+
 import contextlib
 import inspect
 import pathlib
@@ -53,7 +55,7 @@ source_suffix = {".rst": "restructuredtext", ".md": "markdown"}
 master_doc = "index"
 
 project = about["__title__"]
-copyright = about["__copyright__"]
+project_copyright = about["__copyright__"]
 
 version = "%s" % (".".join(about["__version__"].split("."))[:2])
 release = "%s" % (about["__version__"])
@@ -87,7 +89,7 @@ html_theme_options: t.Dict[str, t.Union[str, t.List[t.Dict[str, str]]]] = {
     "source_repository": f"{about['__github__']}/",
     "source_branch": "master",
     "source_directory": "docs/",
-    "announcement": "<em>Friendly reminder:</em> 📌 Pin the package, libtmux is pre-1.0 and APIs will be <a href='/migration.html'>changing</a> throughout 2022-2023.",
+    "announcement": "<em>Friendly reminder:</em> 📌 Pin the package, libtmux is pre-1.0 and APIs will be <a href='/migration.html'>changing</a> throughout 2022-2024.",
 }
 html_sidebars = {
     "**": [
@@ -97,7 +99,7 @@ html_sidebars = {
         "sidebar/navigation.html",
         "sidebar/projects.html",
         "sidebar/scroll-end.html",
-    ]
+    ],
 }
 
 # linkify_issues
@@ -122,43 +124,8 @@ rediraffe_branch = "master~1"
 # sphinxext.opengraph
 ogp_site_url = about["__docs__"]
 ogp_image = "_static/img/icons/icon-192x192.png"
-ogp_description_length = about["__description__"]
 ogp_site_name = about["__title__"]
 
-htmlhelp_basename = f"{about['__title__']}doc"
-
-latex_documents = [
-    (
-        "index",
-        f"{about['__package_name__']}.tex",
-        f"{about['__title__']} Documentation",
-        about["__author__"],
-        "manual",
-    )
-]
-
-man_pages = [
-    (
-        "index",
-        about["__package_name__"],
-        f"{about['__title__']} Documentation",
-        about["__author__"],
-        1,
-    )
-]
-
-texinfo_documents = [
-    (
-        "index",
-        about["__package_name__"],
-        f"{about['__title__']} Documentation",
-        about["__author__"],
-        about["__package_name__"],
-        about["__description__"],
-        "Miscellaneous",
-    )
-]
-
 intersphinx_mapping = {
     "": ("https://docs.python.org/", None),
     "pytest": ("https://docs.pytest.org/en/stable/", None),
@@ -167,7 +134,7 @@ intersphinx_mapping = {
 
 def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     """
-    Determine the URL corresponding to Python object
+    Determine the URL corresponding to Python object.
 
     Notes
     -----
@@ -237,6 +204,7 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
 
 
 def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
+    """Remove tabs.js from _static after build."""
     # Fix for sphinx-inline-tabs#18
     if app.builder.format == "html" and not exc:
         tabs_js = pathlib.Path(app.builder.outdir) / "_static" / "tabs.js"
@@ -245,4 +213,5 @@ def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
 
 
 def setup(app: "Sphinx") -> None:
+    """Configure Sphinx app hooks."""
     app.connect("build-finished", remove_tabs_js)
