@@ -1,4 +1,5 @@
 """Helper methods for libtmux and downstream libtmux libraries."""
+
 import contextlib
 import logging
 import os
@@ -25,8 +26,11 @@ RETRY_INTERVAL_SECONDS = float(os.getenv("RETRY_INTERVAL_SECONDS", 0.05))
 
 
 class RandomStrSequence:
+    """Factory to generate random string."""
+
     def __init__(
-        self, characters: str = "abcdefghijklmnopqrstuvwxyz0123456789_"
+        self,
+        characters: str = "abcdefghijklmnopqrstuvwxyz0123456789_",
     ) -> None:
         """Create a random letter / number generator. 8 chars in length.
 
@@ -41,9 +45,11 @@ class RandomStrSequence:
         self.characters: str = characters
 
     def __iter__(self) -> "RandomStrSequence":
+        """Return self."""
         return self
 
     def __next__(self) -> str:
+        """Return next random string."""
         return "".join(random.sample(self.characters, k=8))
 
 
@@ -75,12 +81,12 @@ def retry_until(
         Time in seconds to wait between calls. Defaults to ``0.05`` and is
         configurable via ``RETRY_INTERVAL_SECONDS`` environment variable.
     raises : bool
-        Wether or not to raise an exception on timeout. Defaults to ``True``.
+        Whether or not to raise an exception on timeout. Defaults to ``True``.
 
     Examples
     --------
     >>> def fn():
-    ...     p = session.attached_window.attached_pane
+    ...     p = session.active_window.active_pane
     ...     return p.pane_current_path is not None
 
     >>> retry_until(fn)
@@ -137,7 +143,8 @@ def get_test_session_name(server: "Server", prefix: str = TEST_SESSION_PREFIX) -
 
 
 def get_test_window_name(
-    session: "Session", prefix: t.Optional[str] = TEST_SESSION_PREFIX
+    session: "Session",
+    prefix: t.Optional[str] = TEST_SESSION_PREFIX,
 ) -> str:
     """
     Faker to create a window name that doesn't exist.
@@ -176,7 +183,9 @@ def get_test_window_name(
 
 @contextlib.contextmanager
 def temp_session(
-    server: Server, *args: t.Any, **kwargs: t.Any
+    server: Server,
+    *args: t.Any,
+    **kwargs: t.Any,
 ) -> t.Generator["Session", t.Any, t.Any]:
     """
     Return a context manager with a temporary session.
@@ -184,8 +193,7 @@ def temp_session(
     If no ``session_name`` is entered, :func:`get_test_session_name` will make
     an unused session name.
 
-    The session will destroy itself upon closing with :meth:`Session.
-    kill_session()`.
+    The session will destroy itself upon closing with :meth:`Session.session()`.
 
     Parameters
     ----------
@@ -209,7 +217,6 @@ def temp_session(
     ...     session.new_window(window_name='my window')
     Window(@3 2:my window, Session($... ...))
     """
-
     if "session_name" in kwargs:
         session_name = kwargs.pop("session_name")
     else:
@@ -221,19 +228,21 @@ def temp_session(
         yield session
     finally:
         if server.has_session(session_name):
-            session.kill_session()
+            session.kill()
     return
 
 
 @contextlib.contextmanager
 def temp_window(
-    session: "Session", *args: t.Any, **kwargs: t.Any
+    session: "Session",
+    *args: t.Any,
+    **kwargs: t.Any,
 ) -> t.Generator["Window", t.Any, t.Any]:
     """
     Return a context manager with a temporary window.
 
     The window will destroy itself upon closing with :meth:`window.
-    kill_window()`.
+    kill()`.
 
     If no ``window_name`` is entered, :func:`get_test_window_name` will make
     an unused window name.
@@ -262,7 +271,7 @@ def temp_window(
 
 
     >>> with temp_window(session) as window:
-    ...     window.split_window()
+    ...     window.split()
     Pane(%4 Window(@3 2:libtmux_..., Session($1 libtmux_...)))
     """
     if "window_name" not in kwargs:
@@ -281,12 +290,12 @@ def temp_window(
         yield window
     finally:
         if len(session.windows.filter(window_id=window_id)) > 0:
-            window.kill_window()
+            window.kill()
     return
 
 
 class EnvironmentVarGuard:
-    """Mock environmental variables safetly.
+    """Mock environmental variables safely.
 
     Helps rotect the environment variable properly.  Can be used as context
     manager.
@@ -309,6 +318,7 @@ class EnvironmentVarGuard:
         self._reset: t.Dict[str, str] = {}
 
     def set(self, envvar: str, value: str) -> None:
+        """Set environment variable."""
         if envvar not in self._environ:
             self._unset.add(envvar)
         else:
@@ -316,11 +326,13 @@ class EnvironmentVarGuard:
         self._environ[envvar] = value
 
     def unset(self, envvar: str) -> None:
+        """Unset environment variable."""
         if envvar in self._environ:
             self._reset[envvar] = self._environ[envvar]
             del self._environ[envvar]
 
     def __enter__(self) -> "EnvironmentVarGuard":
+        """Return context for for context manager."""
         return self
 
     def __exit__(
@@ -329,6 +341,7 @@ class EnvironmentVarGuard:
         exc_value: t.Optional[BaseException],
         exc_tb: t.Optional[types.TracebackType],
     ) -> None:
+        """Cleanup to run after context manager finishes."""
         for envvar, value in self._reset.items():
             self._environ[envvar] = value
         for unset in self._unset:
