@@ -4,21 +4,26 @@ libtmux.window
 ~~~~~~~~~~~~~~
 
 """
+
 import dataclasses
 import logging
-import pathlib
 import shlex
 import typing as t
 import warnings
 
 from libtmux._internal.query_list import QueryList
 from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.constants import (
+    RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    PaneDirection,
+    ResizeAdjustmentDirection,
+    WindowDirection,
+)
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
 
 from . import exc
 from .common import PaneDict, WindowOptionDict, handle_option_error
-from .formats import FORMAT_SEPARATOR
 
 if t.TYPE_CHECKING:
     from .server import Server
@@ -39,7 +44,7 @@ class Window(Obj):
 
     Examples
     --------
-    >>> window = session.new_window('My project')
+    >>> window = session.new_window('My project', attach=True)
 
     >>> window
     Window(@2 2:My project, Session($... ...))
@@ -49,7 +54,7 @@ class Window(Obj):
     >>> window.panes
     [Pane(...)]
 
-    >>> window.attached_pane
+    >>> window.active_pane
     Pane(...)
 
     Relations moving up:
@@ -57,10 +62,10 @@ class Window(Obj):
     >>> window.session
     Session(...)
 
-    >>> window.window_id == session.attached_window.window_id
+    >>> window.window_id == session.active_window.window_id
     True
 
-    >>> window == session.attached_window
+    >>> window == session.active_window
     True
 
     >>> window in session.windows
@@ -85,6 +90,7 @@ class Window(Obj):
             obj_key="window_id",
             obj_id=self.window_id,
             list_cmd="list-windows",
+            list_extra_args=("-a",),
         )
 
     @classmethod
@@ -131,18 +137,43 @@ class Window(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Execute tmux subcommand against target window. See :meth:`Server.cmd`.
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+        target: t.Optional[t.Union[str, int]] = None,
+    ) -> tmux_cmd:
+        """Execute tmux subcommand within window context.
 
-        Send command to tmux with :attr:`window_id` as ``target-window``.
+        Automatically binds target by adding  ``-t`` for object's window ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
-        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
-        ``args`` will override using the object's ``window_id`` as target.
+        Examples
+        --------
+        Create a pane from a window:
+
+        >>> window.cmd('split-window', '-P', '-F#{pane_id}').stdout[0]
+        '%...'
+
+        Magic, directly to a `Pane`:
+
+        >>> Pane.from_pane_id(pane_id=session.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=session.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the window ID.
+
+        Returns
+        -------
+        :meth:`server.cmd`
         """
-        if not any(arg.startswith("-t") for arg in args):
-            args = ("-t", self.window_id, *args)
+        if target is None:
+            target = self.window_id
 
-        return self.server.cmd(cmd, *args, **kwargs)
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
@@ -158,33 +189,34 @@ class Window(Obj):
         target_pane : str
             'target_pane', '-U' ,'-D', '-L', '-R', or '-l'.
 
-        Return
-        ------
+        Returns
+        -------
         :class:`Pane`
         """
         if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
-            proc = self.cmd("select-pane", "-t%s" % self.window_id, target_pane)
+            proc = self.cmd("select-pane", target_pane)
         else:
-            proc = self.cmd("select-pane", "-t%s" % target_pane)
+            proc = self.cmd("select-pane", target=target_pane)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return self.attached_pane
+        return self.active_pane
 
-    def split_window(
+    def split(
         self,
+        /,
         target: t.Optional[t.Union[int, str]] = None,
         start_directory: t.Optional[str] = None,
-        attach: bool = True,
-        vertical: bool = True,
+        attach: bool = False,
+        direction: t.Optional[PaneDirection] = None,
+        full_window_split: t.Optional[bool] = None,
+        zoom: t.Optional[bool] = None,
         shell: t.Optional[str] = None,
-        percent: t.Optional[int] = None,
+        size: t.Optional[t.Union[str, int]] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Pane":
-        """Split window and return the created :class:`Pane`.
-
-        Used for splitting window and holding in a python object.
+        """Split window on active pane and return the created :class:`Pane`.
 
         Parameters
         ----------
@@ -193,10 +225,12 @@ class Window(Obj):
             True.
         start_directory : str, optional
             specifies the working directory in which the new window is created.
-        target : str
-            ``target_pane`` to split.
-        vertical : str
-            split vertically
+        direction : PaneDirection, optional
+            split in direction. If none is specified, assume down.
+        full_window_split: bool, optional
+            split across full window width or height, rather than active pane.
+        zoom: bool, optional
+            expand pane
         shell : str, optional
             execute a command on splitting the window.  The pane will close
             when the command exits.
@@ -204,80 +238,105 @@ class Window(Obj):
             NOTE: When this command exits the pane will close.  This feature
             is useful for long-running processes where the closing of the
             window upon completion is desired.
-        percent: int, optional
-            percentage to occupy with respect to current window
+        size: int, optional
+            Cell/row or percentage to occupy with respect to current window.
         environment: dict, optional
             Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+        """
+        active_pane = self.active_pane or self.panes[0]
+        return active_pane.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=direction,
+            full_window_split=full_window_split,
+            zoom=zoom,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
+    def resize(
+        self,
+        /,
+        # Adjustments
+        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
+        adjustment: t.Optional[int] = None,
+        # Manual
+        height: t.Optional[int] = None,
+        width: t.Optional[int] = None,
+        # Expand / Shrink
+        expand: t.Optional[bool] = None,
+        shrink: t.Optional[bool] = None,
+    ) -> "Window":
+        """Resize tmux window.
+
+        Parameters
+        ----------
+        adjustment_direction : ResizeAdjustmentDirection, optional
+            direction to adjust, ``Up``, ``Down``, ``Left``, ``Right``.
+        adjustment : ResizeAdjustmentDirection, optional
+
+        height : int, optional
+            ``resize-window -y`` dimensions
+        width : int, optional
+            ``resize-window -x`` dimensions
+
+        expand : bool
+            expand window
+        shrink : bool
+            shrink window
+
+        Raises
+        ------
+        :exc:`exc.LibTmuxException`,
+        :exc:`exc.PaneAdjustmentDirectionRequiresAdjustment`
+
+        Returns
+        -------
+        :class:`Window`
 
         Notes
         -----
-        :term:`tmux(1)` will move window to the new pane if the
-        ``split-window`` target is off screen. tmux handles the ``-d`` the
-        same way as ``new-window`` and ``attach`` in
-        :class:`Session.new_window`.
+        Three types of resizing are available:
 
-        By default, this will make the window the pane is created in
-        active. To remain on the same window and split the pane in another
-        target window, pass in ``attach=False``.
+        1. Adjustments: ``adjustment_direction`` and ``adjustment``.
+        2. Manual resizing: ``height`` and / or ``width``.
+        3. Expand or shrink: ``expand`` or ``shrink``.
         """
-        tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
+        if not has_gte_version("2.9"):
+            warnings.warn("resize() requires tmux 2.9 or newer", stacklevel=2)
+            return self
 
         tmux_args: t.Tuple[str, ...] = ()
 
-        if target is not None:
-            tmux_args += ("-t%s" % target,)
-        else:
-            if len(self.panes):
-                tmux_args += (
-                    f"-t{self.session_id}:{self.window_id}.{self.panes[0].pane_index}",
-                )
-            else:
-                tmux_args += (f"-t{self.session_id}:{self.window_id}",)
+        ## Adjustments
+        if adjustment_direction:
+            if adjustment is None:
+                raise exc.WindowAdjustmentDirectionRequiresAdjustment()
+            tmux_args += (
+                f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
+                str(adjustment),
+            )
+        elif height or width:
+            ## Manual resizing
+            if height:
+                tmux_args += (f"-y{int(height)}",)
+            if width:
+                tmux_args += (f"-x{int(width)}",)
+        elif expand or shrink:
+            if expand:
+                tmux_args += ("-A",)
+            elif shrink:
+                tmux_args += ("-a",)
 
-        if vertical:
-            tmux_args += ("-v",)
-        else:
-            tmux_args += ("-h",)
+        proc = self.cmd("resize-window", *tmux_args)
 
-        if percent is not None:
-            tmux_args += ("-p %d" % percent,)
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
 
-        tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
-
-        if start_directory is not None:
-            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
-            start_path = pathlib.Path(start_directory).expanduser()
-            tmux_args += (f"-c{start_path}",)
-
-        if not attach:
-            tmux_args += ("-d",)
-
-        if environment:
-            if has_gte_version("3.0"):
-                for k, v in environment.items():
-                    tmux_args += (f"-e{k}={v}",)
-            else:
-                logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required.",
-                )
-
-        if shell:
-            tmux_args += (shell,)
-
-        pane_cmd = self.cmd("split-window", *tmux_args)
-
-        # tmux < 1.7. This is added in 1.7.
-        if pane_cmd.stderr:
-            if "pane too small" in pane_cmd.stderr:
-                raise exc.LibTmuxException(pane_cmd.stderr)
-
-            raise exc.LibTmuxException(pane_cmd.stderr, self.__dict__, self.panes)
-
-        pane_output = pane_cmd.stdout[0]
-
-        pane_formatters = dict(zip(["pane_id"], pane_output.split(FORMAT_SEPARATOR)))
-
-        return Pane.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
+        self.refresh()
+        return self
 
     def last_pane(self) -> t.Optional["Pane"]:
         """Return last pane."""
@@ -314,7 +373,7 @@ class Window(Obj):
             'custom'
                 custom dimensions (see :term:`tmux(1)` manpages).
         """
-        cmd = ["select-layout", f"-t{self.session_id}:{self.window_index}"]
+        cmd = ["select-layout"]
 
         if layout:  # tmux allows select-layout without args
             cmd.append(layout)
@@ -351,7 +410,6 @@ class Window(Obj):
 
         cmd = self.cmd(
             "set-window-option",
-            f"-t{self.session_id}:{self.window_index}",
             option,
             value,
         )
@@ -389,7 +447,10 @@ class Window(Obj):
 
         window_options: "WindowOptionDict" = {}
         for item in output:
-            key, val = shlex.split(item)
+            try:
+                key, val = shlex.split(item)
+            except ValueError:
+                logger.exception(f"Error extracting option: {item}")
             assert isinstance(key, str)
             assert isinstance(val, str)
 
@@ -453,7 +514,7 @@ class Window(Obj):
 
         Examples
         --------
-        >>> window = session.attached_window
+        >>> window = session.active_window
 
         >>> window.rename_window('My project')
         Window(@1 1:My project, Session($1 ...))
@@ -477,16 +538,61 @@ class Window(Obj):
 
         return self
 
-    def kill_window(self) -> None:
-        """Kill the current :class:`Window` object. ``$ tmux kill-window``."""
+    def kill(
+        self,
+        all_except: t.Optional[bool] = None,
+    ) -> None:
+        """Kill :class:`Window`.
+
+        ``$ tmux kill-window``.
+
+        Examples
+        --------
+        Kill a window:
+
+        >>> window_1 = session.new_window()
+
+        >>> window_1 in session.windows
+        True
+
+        >>> window_1.kill()
+
+        >>> window_1 not in session.windows
+        True
+
+        Kill all windows except the current one:
+
+        >>> one_window_to_rule_them_all = session.new_window()
+
+        >>> other_windows = session.new_window(
+        ...     ), session.new_window()
+
+        >>> all([w in session.windows for w in other_windows])
+        True
+
+        >>> one_window_to_rule_them_all.kill(all_except=True)
+
+        >>> all([w not in session.windows for w in other_windows])
+        True
+
+        >>> one_window_to_rule_them_all in session.windows
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if all_except:
+            flags += ("-a",)
+
         proc = self.cmd(
             "kill-window",
-            f"-t{self.session_id}:{self.window_index}",
+            *flags,
         )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        return None
+
     def move_window(
         self,
         destination: str = "",
@@ -507,7 +613,7 @@ class Window(Obj):
         proc = self.cmd(
             "move-window",
             f"-s{self.session_id}:{self.window_index}",
-            f"-t{session}:{destination}",
+            target=f"{session}:{destination}",
         )
 
         if proc.stderr:
@@ -520,28 +626,110 @@ class Window(Obj):
 
         return self
 
+    def new_window(
+        self,
+        window_name: t.Optional[str] = None,
+        *,
+        start_directory: None = None,
+        attach: bool = False,
+        window_index: str = "",
+        window_shell: t.Optional[str] = None,
+        environment: t.Optional[t.Dict[str, str]] = None,
+        direction: t.Optional[WindowDirection] = None,
+    ) -> "Window":
+        """Create new window respective of current window's position.
+
+        See Also
+        --------
+        :meth:`Session.new_window()`
+
+        Examples
+        --------
+        .. ::
+            >>> import pytest
+            >>> from libtmux.common import has_lt_version
+            >>> if has_lt_version('3.2'):
+            ...     pytest.skip('This doctest requires tmux 3.2 or newer')
+        >>> window_initial = session.new_window(window_name='Example')
+        >>> window_initial
+        Window(@... 2:Example, Session($1 libtmux_...))
+        >>> window_initial.window_index
+        '2'
+
+        >>> window_before = window_initial.new_window(
+        ... window_name='Window before', direction=WindowDirection.Before)
+        >>> window_initial.refresh()
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+
+        >>> window_after = window_initial.new_window(
+        ... window_name='Window after', direction=WindowDirection.After)
+        >>> window_initial.refresh()
+        >>> window_after.refresh()
+        >>> window_after
+        Window(@... 4:Window after, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        """
+        return self.session.new_window(
+            window_name=window_name,
+            start_directory=start_directory,
+            attach=attach,
+            window_index=window_index,
+            window_shell=window_shell,
+            environment=environment,
+            direction=direction,
+            target_window=self.window_id,
+        )
+
     #
     # Climbers
     #
-    def select_window(self) -> "Window":
+    def select(self) -> "Window":
         """Select window.
 
         To select a window object asynchrously. If a ``window`` object exists
-        and is no longer longer the current window, ``w.select_window()``
+        and is no longer the current window, ``w.select_window()``
         will make ``w`` the current window.
+
+        Examples
+        --------
+        >>> window = session.active_window
+        >>> new_window = session.new_window()
+        >>> session.refresh()
+        >>> active_windows = [w for w in session.windows if w.window_active == '1']
+
+        >>> new_window.window_active == '1'
+        False
+
+        >>> new_window.select()
+        Window(...)
+
+        >>> new_window.window_active == '1'
+        True
         """
-        assert isinstance(self.window_index, str)
-        return self.session.select_window(self.window_index)
+        proc = self.cmd("select-window")
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        self.refresh()
+
+        return self
 
     #
     # Computed properties
     #
     @property
-    def attached_pane(self) -> t.Optional["Pane"]:
+    def active_pane(self) -> t.Optional["Pane"]:
         """Return attached :class:`Pane`."""
-        for pane in self.panes:
-            if pane.pane_active == "1":
-                return pane
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
         return None
 
     #
@@ -555,12 +743,9 @@ class Window(Obj):
 
     def __repr__(self) -> str:
         """Representation of :class:`Window` object."""
-        return "{}({} {}:{}, {})".format(
-            self.__class__.__name__,
-            self.window_id,
-            self.window_index,
-            self.window_name,
-            self.session,
+        return (
+            f"{self.__class__.__name__}({self.window_id} "
+            + f"{self.window_index}:{self.window_name}, {self.session})"
         )
 
     #
@@ -629,6 +814,116 @@ class Window(Obj):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    def split_window(
+        self,
+        target: t.Optional[t.Union[int, str]] = None,
+        start_directory: t.Optional[str] = None,
+        attach: bool = False,
+        vertical: bool = True,
+        shell: t.Optional[str] = None,
+        size: t.Optional[t.Union[str, int]] = None,
+        percent: t.Optional[int] = None,  # deprecated
+        environment: t.Optional[t.Dict[str, str]] = None,
+    ) -> "Pane":
+        """Split window and return the created :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.33.0
+
+           Deprecated in favor of :meth:`.split()`.
+
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
+        .. deprecated:: 0.28.0
+
+           ``percent=25`` deprecated in favor of ``size="25%"``.
+        """
+        warnings.warn(
+            "Window.split_window() is deprecated in favor of Window.split()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+
+        if percent is not None:
+            # Deprecated in 3.1 in favor of -l
+            warnings.warn(
+                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
+                + ' ("-l" flag) in tmux 3.1+.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+            if size is None:
+                size = f"{str(percent).rstrip('%')}%"
+
+        return self.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=PaneDirection.Below if vertical else PaneDirection.Right,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
+    @property
+    def attached_pane(self) -> t.Optional["Pane"]:
+        """Return attached :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.31
+
+           Deprecated in favor of :meth:`.active_pane`.
+        """
+        warnings.warn(
+            "Window.attached_pane() is deprecated in favor of Window.active_pane()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        panes = self.panes.filter(pane_active="1")
+        if len(panes) > 0:
+            return panes[0]
+        return None
+
+    def select_window(self) -> "Window":
+        """Select window.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.select()`.
+        """
+        warnings.warn(
+            "Window.select_window() is deprecated in favor of Window.select()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        assert isinstance(self.window_index, str)
+        return self.session.select_window(self.window_index)
+
+    def kill_window(self) -> None:
+        """Kill the current :class:`Window` object. ``$ tmux kill-window``.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.kill()`.
+        """
+        warnings.warn(
+            "Window.kill_server() is deprecated in favor of Window.kill()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd("kill-window")
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
@@ -638,7 +933,9 @@ class Window(Obj):
            accessed via ``window.window_name``.
 
         """
-        warnings.warn("Window.get() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.get() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
@@ -650,7 +947,11 @@ class Window(Obj):
            accessed via ``window.window_name``.
 
         """
-        warnings.warn(f"Item lookups, e.g. window['{key}'] is deprecated", stacklevel=2)
+        warnings.warn(
+            f"Item lookups, e.g. window['{key}'] is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return getattr(self, key)
 
     def get_by_id(self, pane_id: str) -> t.Optional[Pane]:
@@ -661,7 +962,11 @@ class Window(Obj):
            Deprecated by :meth:`.panes.get()`.
 
         """
-        warnings.warn("Window.get_by_id() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.get_by_id() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.panes.get(pane_id=pane_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Pane]:
@@ -672,7 +977,9 @@ class Window(Obj):
            Deprecated by :meth:`.panes.filter()`.
 
         """
-        warnings.warn("Window.where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.where() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         try:
             return self.panes.filter(**kwargs)
         except IndexError:
@@ -686,7 +993,11 @@ class Window(Obj):
            Slated to be removed in favor of :meth:`.panes.get()`.
 
         """
-        warnings.warn("Window.find_where() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.panes.get(default=None, **kwargs)
 
     def _list_panes(self) -> t.List[PaneDict]:
@@ -697,7 +1008,11 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("Window._list_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "Window._list_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [pane.__dict__ for pane in self.panes]
 
     @property
@@ -709,7 +1024,7 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("_panes is deprecated", stacklevel=2)
+        warnings.warn("_panes is deprecated", category=DeprecationWarning, stacklevel=2)
         return self._list_panes()
 
     def list_panes(self) -> t.List["Pane"]:
@@ -720,7 +1035,9 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("list_panes() is deprecated", stacklevel=2)
+        warnings.warn(
+            "list_panes() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.panes
 
     @property
@@ -732,5 +1049,7 @@ class Window(Obj):
            Slated to be removed in favor of :attr:`.panes`.
 
         """
-        warnings.warn("Server.children is deprecated", stacklevel=2)
+        warnings.warn(
+            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.panes
