@@ -1,4 +1,5 @@
 """Test for libtmux Window object."""
+
 import logging
 import shutil
 import time
@@ -8,7 +9,12 @@ import pytest
 
 from libtmux import exc
 from libtmux._internal.query_list import ObjectDoesNotExist
-from libtmux.common import has_gte_version, has_lt_version
+from libtmux.common import has_gte_version, has_lt_version, has_lte_version
+from libtmux.constants import (
+    PaneDirection,
+    ResizeAdjustmentDirection,
+    WindowDirection,
+)
 from libtmux.pane import Pane
 from libtmux.server import Server
 from libtmux.session import Session
@@ -24,66 +30,66 @@ def test_select_window(session: Session) -> None:
     # for now however, let's get the index from the first window.
     assert window_count == 1
 
-    assert session.attached_window.window_index is not None
-    window_base_index = int(session.attached_window.window_index)
+    assert session.active_window.window_index is not None
+    window_base_index = int(session.active_window.window_index)
 
     window = session.new_window(window_name="testing 3")
 
     # self.assertEqual(2,
-    # int(session.attached_window.index))
+    # int(session.active_window.index))
     assert window.window_index is not None
     assert int(window_base_index) + 1 == int(window.window_index)
 
     session.select_window(str(window_base_index))
-    assert window_base_index == int(session.attached_window.window_index)
+    assert window_base_index == int(session.active_window.window_index)
 
     session.select_window("testing 3")
-    assert session.attached_window.window_index is not None
-    assert int(window_base_index) + 1 == int(session.attached_window.window_index)
+    assert session.active_window.window_index is not None
+    assert int(window_base_index) + 1 == int(session.active_window.window_index)
 
     assert len(session.windows) == 2
 
 
 def test_fresh_window_data(session: Session) -> None:
     """Verify window data is fresh."""
-    attached_window = session.attached_window
-    assert attached_window is not None
-    pane_base_idx = attached_window.show_window_option("pane-base-index", g=True)
+    active_window = session.active_window
+    assert active_window is not None
+    pane_base_idx = active_window.show_window_option("pane-base-index", g=True)
     assert pane_base_idx is not None
     pane_base_index = int(pane_base_idx)
 
     assert len(session.windows) == 1
 
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     current_windows = len(session.windows)
     assert session.session_id != "@0"
     assert current_windows == 1
 
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     assert isinstance(session.server, Server)
-    # len(session.attached_window.panes))
+    # len(session.active_window.panes))
 
     assert len(session.windows), 1
-    assert len(session.attached_window.panes) == 1
+    assert len(session.active_window.panes) == 1
     for w in session.windows:
         assert isinstance(w, Window)
-    window = session.attached_window
+    window = session.active_window
     assert isinstance(window, Window)
-    assert len(session.attached_window.panes) == 1
-    window.split_window()
+    assert len(session.active_window.panes) == 1
+    window.split()
 
-    attached_window = session.attached_window
-    assert attached_window is not None
-    attached_window.select_pane(pane_base_index)
+    active_window = session.active_window
+    assert active_window is not None
+    active_window.select_pane(pane_base_index)
 
-    attached_pane = session.attached_pane
-    assert attached_pane is not None
-    attached_pane.send_keys("cd /srv/www/flaskr")
+    active_pane = session.active_pane
+    assert active_pane is not None
+    active_pane.send_keys("cd /srv/www/flaskr")
 
-    attached_window.select_pane(pane_base_index + 1)
-    attached_pane = session.attached_pane
-    assert attached_pane is not None
-    attached_pane.send_keys("source .venv/bin/activate")
+    active_window.select_pane(pane_base_index + 1)
+    active_pane = session.active_pane
+    assert active_pane is not None
+    active_pane.send_keys("source .venv/bin/activate")
     session.new_window(window_name="second")
     current_windows += 1
     assert current_windows == len(session.windows)
@@ -102,26 +108,26 @@ def test_newest_pane_data(session: Session) -> None:
     window = session.new_window(window_name="test", attach=True)
     assert isinstance(window, Window)
     assert len(window.panes) == 1
-    window.split_window(attach=True)
+    window.split(attach=True)
 
     assert len(window.panes) == 2
-    # note: the below used to accept -h, removing because split_window now
+    # note: the below used to accept -h, removing because split now
     # has attach as its only argument now
-    window.split_window(attach=True)
+    window.split(attach=True)
     assert len(window.panes) == 3
 
 
-def test_attached_pane(session: Session) -> None:
-    """Window.attached_window returns active Pane."""
-    window = session.attached_window  # current window
-    assert isinstance(window.attached_pane, Pane)
+def test_active_pane(session: Session) -> None:
+    """Window.active_window returns active Pane."""
+    window = session.active_window  # current window
+    assert isinstance(window.active_pane, Pane)
 
 
-def test_split_window(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, vertical."""
+def test_split(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, vertical."""
     window_name = "test split window"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window()
+    pane = window.split()
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -132,12 +138,12 @@ def test_split_window(session: Session) -> None:
     assert float(first_pane.pane_height) <= ((float(window.window_width) + 1) / 2)
 
 
-def test_split_window_shell(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, vertical."""
+def test_split_shell(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, vertical."""
     window_name = "test split window"
     cmd = "sleep 1m"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window(shell=cmd)
+    pane = window.split(shell=cmd)
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -154,11 +160,11 @@ def test_split_window_shell(session: Session) -> None:
         assert pane.pane_start_command == cmd
 
 
-def test_split_window_horizontal(session: Session) -> None:
-    """Window.split_window() splits window, returns new Pane, horizontal."""
+def test_split_horizontal(session: Session) -> None:
+    """Window.split() splits window, returns new Pane, horizontal."""
     window_name = "test split window"
     window = session.new_window(window_name=window_name, attach=True)
-    pane = window.split_window(vertical=False)
+    pane = window.split(direction=PaneDirection.Right)
     assert len(window.panes) == 2
     assert isinstance(pane, Pane)
 
@@ -170,12 +176,45 @@ def test_split_window_horizontal(session: Session) -> None:
     assert float(first_pane.pane_width) <= ((float(window.window_width) + 1) / 2)
 
 
+def test_split_size(session: Session) -> None:
+    """Window.split() respects size."""
+    window = session.new_window(window_name="split window size")
+    window.resize(height=100, width=100)
+
+    if has_gte_version("3.1"):
+        pane = window.split(size=10)
+        assert pane.pane_height == "10"
+
+        pane = window.split(direction=PaneDirection.Right, size=10)
+        assert pane.pane_width == "10"
+
+        pane = window.split(size="10%")
+        assert pane.pane_height == "8"
+
+        pane = window.split(direction=PaneDirection.Right, size="10%")
+        assert pane.pane_width == "8"
+    else:
+        window_height_before = (
+            int(window.window_height) if isinstance(window.window_height, str) else 0
+        )
+        window_width_before = (
+            int(window.window_width) if isinstance(window.window_width, str) else 0
+        )
+        pane = window.split(size="10%")
+        assert pane.pane_height == str(int(window_height_before * 0.1))
+
+        pane = window.split(direction=PaneDirection.Right, size="10%")
+        assert pane.pane_width == str(int(window_width_before * 0.1))
+
+
 @pytest.mark.parametrize(
     "window_name_before,window_name_after",
     [("test", "ha ha ha fjewlkjflwef"), ("test", "hello \\ wazzup 0")],
 )
 def test_window_rename(
-    session: Session, window_name_before: str, window_name_after: str
+    session: Session,
+    window_name_before: str,
+    window_name_after: str,
 ) -> None:
     """Test Window.rename_window()."""
     window_name_before = "test"
@@ -184,16 +223,16 @@ def test_window_rename(
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name=window_name_before, attach=True)
 
-    assert window == session.attached_window
+    assert window == session.active_window
     assert window.window_name == window_name_before
 
     window.rename_window(window_name_after)
 
-    window = session.attached_window
+    window = session.active_window
 
     assert window.window_name == window_name_after
 
-    window = session.attached_window
+    window = session.active_window
 
     assert window.window_name == window_name_after
 
@@ -204,7 +243,7 @@ def test_kill_window(session: Session) -> None:
     # create a second window to not kick out the client.
     # there is another way to do this via options too.
 
-    w = session.attached_window
+    w = session.active_window
 
     assert w.window_id is not None
 
@@ -320,14 +359,15 @@ def test_select_layout_accepts_no_arg(server: Server, session: Session) -> None:
 
 
 @pytest.mark.skipif(
-    has_lt_version("3.2"), reason="needs filter introduced in tmux >= 3.2"
+    has_lt_version("3.2"),
+    reason="needs filter introduced in tmux >= 3.2",
 )
 def test_empty_window_name(session: Session) -> None:
     """New windows can be created with empty string for window name."""
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name="''", attach=True)
 
-    assert window == session.attached_window
+    assert window == session.active_window
     assert window.window_name == "''"
     assert session.session_name is not None
 
@@ -352,7 +392,7 @@ def test_empty_window_name(session: Session) -> None:
         {"ENV_VAR_1": "pane_1", "ENV_VAR_2": "pane_2"},
     ],
 )
-def test_split_window_with_environment(
+def test_split_with_environment(
     session: Session,
     environment: t.Dict[str, str],
 ) -> None:
@@ -360,8 +400,8 @@ def test_split_window_with_environment(
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
-    window = session.new_window(window_name="split_window_with_environment")
-    pane = window.split_window(
+    window = session.new_window(window_name="split_with_environment")
+    pane = window.split(
         shell=f"{env} PS1='$ ' sh",
         environment=environment,
     )
@@ -373,11 +413,37 @@ def test_split_window_with_environment(
         assert pane.capture_pane()[-2] == v
 
 
+@pytest.mark.skipif(
+    has_lte_version("3.1"),
+    reason="3.2 has the -Z flag on split-window",
+)
+def test_split_window_zoom(
+    session: Session,
+) -> None:
+    """Verify splitting window with zoom."""
+    window_without_zoom = session.new_window(window_name="split_without_zoom")
+    window_with_zoom = session.new_window(window_name="split_with_zoom")
+    pane_without_zoom = window_without_zoom.split(
+        zoom=False,
+    )
+    pane_with_zoom = window_with_zoom.split(
+        zoom=True,
+    )
+
+    assert pane_without_zoom.width == pane_without_zoom.window_width
+    assert pane_without_zoom.height is not None
+    assert pane_without_zoom.window_height is not None
+    assert pane_without_zoom.height < pane_without_zoom.window_height
+
+    assert pane_with_zoom.width == pane_with_zoom.window_width
+    assert pane_with_zoom.height == pane_with_zoom.window_height
+
+
 @pytest.mark.skipif(
     has_gte_version("3.0"),
     reason="3.0 has the -e flag on split-window",
 )
-def test_split_window_with_environment_logs_warning_for_old_tmux(
+def test_split_with_environment_logs_warning_for_old_tmux(
     session: Session,
     caplog: pytest.LogCaptureFixture,
 ) -> None:
@@ -385,12 +451,149 @@ def test_split_window_with_environment_logs_warning_for_old_tmux(
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
-    window = session.new_window(window_name="split_window_with_environment")
-    window.split_window(
+    window = session.new_window(window_name="split_with_environment")
+    window.split(
         shell=f"{env} PS1='$ ' sh",
         environment={"ENV_VAR": "pane"},
     )
 
     assert any(
-        "Cannot set up environment" in record.msg for record in caplog.records
+        "Environment flag ignored" in record.msg for record in caplog.records
+    ), "Warning missing"
+
+
+@pytest.mark.skipif(
+    has_lt_version("2.9"),
+    reason="resize-window only exists in tmux 2.9+",
+)
+def test_resize(
+    session: Session,
+) -> None:
+    """Verify resizing window."""
+    session.cmd("detach-client", "-s")
+
+    window = session.active_window
+    window_height_adjustment = 10
+
+    assert window.window_height is not None
+    assert window.window_width is not None
+
+    #
+    # Manual resizing
+    #
+
+    # Manual: Height
+    window_height_before = int(window.window_height)
+    window.resize(
+        height=10,
+    )
+    assert int(window.window_height) == 10
+
+    # Manual: Width
+    window.resize(
+        width=10,
+    )
+    assert int(window.window_width) == 10
+
+    #
+    # Adjustments
+    #
+
+    # Adjustment: Down
+    window_height_before = int(window.window_height)
+    window.resize(
+        adjustment_direction=ResizeAdjustmentDirection.Down,
+        adjustment=window_height_adjustment * 2,
+    )
+    assert window_height_before + (window_height_adjustment * 2) == int(
+        window.window_height
+    )
+
+    # Adjustment: Up
+    window_height_before = int(window.window_height)
+    window.resize(
+        adjustment_direction=ResizeAdjustmentDirection.Up,
+        adjustment=window_height_adjustment,
+    )
+    assert window_height_before - window_height_adjustment == int(window.window_height)
+
+    #
+    # Shrink and expand
+    #
+    window.resize(height=50)
+
+    # Shrink
+    window_height_before = int(window.window_height)
+    window.resize(
+        shrink=True,
+    )
+    window_height_shrunk = int(window.window_height)
+    assert window_height_before > window_height_shrunk
+
+    assert window
+
+    # Expand
+    window.resize(height=2)
+    window_height_before = int(window.window_height)
+    window.resize(
+        expand=True,
+    )
+    window_height_expanded = int(window.window_height)
+    assert window_height_before < window_height_expanded
+
+
+@pytest.mark.skipif(
+    has_lt_version("3.2"),
+    reason="Only 3.2+ has the -a and -b flag on new-window",
+)
+def test_new_window_with_direction(
+    session: Session,
+) -> None:
+    """Verify new window with direction."""
+    window = session.active_window
+    window.refresh()
+
+    window_initial = session.new_window(window_name="Example")
+    assert window_initial.window_index == "2"
+
+    window_before = window_initial.new_window(
+        window_name="Window before", direction=WindowDirection.Before
+    )
+    window_initial.refresh()
+    assert window_before.window_index == "2"
+    assert window_initial.window_index == "3"
+
+    window_after = window_initial.new_window(
+        window_name="Window after", direction=WindowDirection.After
+    )
+    window_initial.refresh()
+    window_after.refresh()
+    assert window_after.window_index == "4"
+    assert window_initial.window_index == "3"
+    assert window_before.window_index == "2"
+
+
+@pytest.mark.skipif(
+    has_gte_version("3.2"),
+    reason="Only 3.2+ has the -a and -b flag on new-window",
+)
+def test_new_window_with_direction_logs_warning_for_old_tmux(
+    session: Session,
+    caplog: pytest.LogCaptureFixture,
+) -> None:
+    """Verify new window with direction create a warning if tmux is too old."""
+    window = session.active_window
+    window.refresh()
+
+    window.new_window(
+        window_name="window_with_direction",
+        direction=WindowDirection.After,
+    )
+
+    assert any(
+        "Window target ignored" in record.msg for record in caplog.records
+    ), "Warning missing"
+
+    assert any(
+        "Direction flag ignored" in record.msg for record in caplog.records
     ), "Warning missing"
